@@ -1,6 +1,6 @@
 ###################################################
 #
-#  Copyright (C) 2008-2013 Mario Kemper <mario.kemper@gmail.com>
+#  Copyright (C) 2008-2012 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
 #
 #  This file is part of Shutter.
 #
@@ -53,8 +53,7 @@ sub new {
 
 sub xdg_open {
 	my ( $self, $dialog, $link, $user_data ) = @_;
-	my @args = ("xdg-open", "$link");
-	system(@args);
+	system("xdg-open $link");
 	if($?){
 		my $response = $self->{_dialogs}->dlg_error_message( 
 			sprintf( $self->{_d}->get("Error while executing %s."), "'xdg-open'"),
@@ -67,12 +66,8 @@ sub xdg_open {
 }
 
 sub xdg_open_mail {
-	my ( $self, $dialog, $mail, @user_data ) = @_;
-
-	my @cmd = 'xdg-email';
-	push @cmd, $mail if $mail;
-	system(@cmd, @user_data);
-
+	my ( $self, $dialog, $mail, $user_data ) = @_;
+	system("xdg-email $mail $user_data");
 	if($?){
 		my $response = $self->{_dialogs}->dlg_error_message( 
 			sprintf( $self->{_d}->get("Error while executing %s."), "'xdg-email'"),
@@ -86,7 +81,7 @@ sub xdg_open_mail {
 
 sub nautilus_sendto {
 	my ( $self, $user_data ) = @_;
-	system('nautilus-sendto', $user_data);
+	system("nautilus-sendto $user_data &");
 	if($?){
 		my $response = $self->{_dialogs}->dlg_error_message( 
 			sprintf( $self->{_d}->get("Error while executing %s."), "'nautilus-sendto'"),
