@@ -1,6 +1,6 @@
 ###################################################
 #
-#  Copyright (C) 2008-2011 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
+#  Copyright (C) 2008-2012 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
 #
 #  This file is part of Shutter.
 #
@@ -16,7 +16,7 @@
 #
 #  You should have received a copy of the GNU General Public License
 #  along with Shutter; if not, write to the Free Software
-#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 #
 ###################################################
 
@@ -168,7 +168,7 @@ sub fct_ret_file_menu {
 
 	$self->{_menuitem_email} = Gtk2::ImageMenuItem->new($d->get('Send by E_mail...'));
 	$self->{_menuitem_email}->set_image(
-		Gtk2::Image->new_from_icon_name( 'gnome-stock-mail-snd', 'menu' )
+		Gtk2::Image->new_from_icon_name( 'mail-send', 'menu' )
 	);
 	$self->{_menuitem_email}->set_sensitive(FALSE);
 	$self->{_menuitem_email}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('<Shift><Control>E'), qw/visible/ );
@@ -233,7 +233,7 @@ sub fct_ret_edit_menu {
 
 	$self->{_menuitem_trash} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('Move to _Trash') );
 	$self->{_menuitem_trash}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('Delete'), qw/visible/ );
-	$self->{_menuitem_trash}->set_image( Gtk2::Image->new_from_icon_name( 'gnome-stock-trash', 'menu' ) );
+	$self->{_menuitem_trash}->set_image( Gtk2::Image->new_from_icon_name( 'user-trash', 'menu' ) );
 	$self->{_menuitem_trash}->set_sensitive(FALSE);
 	$self->{_menu_edit}->append( $self->{_menuitem_trash} );
 
@@ -251,7 +251,7 @@ sub fct_ret_edit_menu {
 	$self->{_menu_edit}->append( Gtk2::SeparatorMenuItem->new );
 
 	$self->{_menuitem_settings} = Gtk2::ImageMenuItem->new_from_stock('gtk-preferences');
-	$self->{_menuitem_settings}->add_accelerator( 'activate', $accel_group, $Gtk2::Gdk::Keysyms{P}, qw/mod1-mask/, qw/visible/ );
+	$self->{_menuitem_settings}->add_accelerator( 'activate', $accel_group, Gtk2::Gdk->keyval_from_name('P'), qw/mod1-mask/, qw/visible/ );
 	$self->{_menu_edit}->append( $self->{_menuitem_settings} );
 
 	return $self->{_menu_edit};
@@ -319,21 +319,21 @@ sub fct_ret_session_menu {
 	$self->{_menu_session} = Gtk2::Menu->new();
 
 	$self->{_menuitem_back} = Gtk2::ImageMenuItem->new_from_stock('gtk-go-back');
-	$self->{_menuitem_back}->add_accelerator( 'activate', $accel_group, $Gtk2::Gdk::Keysyms{Left}, qw/mod1-mask/, qw/visible/ );
+	$self->{_menuitem_back}->add_accelerator( 'activate', $accel_group, Gtk2::Gdk->keyval_from_name('Left'), qw/mod1-mask/, qw/visible/ );
 	$self->{_menu_session}->append( $self->{_menuitem_back} );
 
 	$self->{_menuitem_forward} = Gtk2::ImageMenuItem->new_from_stock('gtk-go-forward');
-	$self->{_menuitem_forward}->add_accelerator( 'activate', $accel_group, $Gtk2::Gdk::Keysyms{Right}, qw/mod1-mask/, qw/visible/ );
+	$self->{_menuitem_forward}->add_accelerator( 'activate', $accel_group, Gtk2::Gdk->keyval_from_name('Right'), qw/mod1-mask/, qw/visible/ );
 	$self->{_menu_session}->append( $self->{_menuitem_forward} );
 
 	$self->{_menu_session}->append( Gtk2::SeparatorMenuItem->new );
 
 	$self->{_menuitem_first} = Gtk2::ImageMenuItem->new_from_stock('gtk-goto-first');
-	$self->{_menuitem_first}->add_accelerator( 'activate', $accel_group, $Gtk2::Gdk::Keysyms{Home}, qw/mod1-mask/, qw/visible/ );
+	$self->{_menuitem_first}->add_accelerator( 'activate', $accel_group, Gtk2::Gdk->keyval_from_name('Home'), qw/mod1-mask/, qw/visible/ );
 	$self->{_menu_session}->append( $self->{_menuitem_first} );
 
 	$self->{_menuitem_last} = Gtk2::ImageMenuItem->new_from_stock('gtk-goto-last');
-	$self->{_menuitem_last}->add_accelerator( 'activate', $accel_group, $Gtk2::Gdk::Keysyms{End}, qw/mod1-mask/, qw/visible/ );
+	$self->{_menuitem_last}->add_accelerator( 'activate', $accel_group, Gtk2::Gdk->keyval_from_name('End'), qw/mod1-mask/, qw/visible/ );
 	$self->{_menu_session}->append( $self->{_menuitem_last} );
 	
 	return $self->{_menu_session};
@@ -398,7 +398,7 @@ sub fct_ret_help_menu {
 	$self->{_menu_help}->append( Gtk2::SeparatorMenuItem->new );
 
 	$self->{_menuitem_about} = Gtk2::ImageMenuItem->new_from_stock('gtk-about');
-	$self->{_menuitem_about}->add_accelerator( 'activate', $accel_group, $Gtk2::Gdk::Keysyms{I}, qw/control-mask/, qw/visible/ );
+	$self->{_menuitem_about}->add_accelerator( 'activate', $accel_group, Gtk2::Gdk->keyval_from_name('I'), qw/control-mask/, qw/visible/ );
 	$self->{_menu_help}->append( $self->{_menuitem_about} );
 
 	return $self->{_menu_help};
@@ -469,8 +469,8 @@ sub fct_ret_new_menu {
 
 	#awindow
 	$self->{_menuitem_awindow} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('_Active Window') );
-	if($icontheme->has_icon('gnome-window-manager')){
-		$self->{_menuitem_awindow}->set_image( Gtk2::Image->new_from_icon_name( 'gnome-window-manager', 'menu' ) );	
+	if($icontheme->has_icon('preferences-system-windows')){
+		$self->{_menuitem_awindow}->set_image( Gtk2::Image->new_from_icon_name( 'preferences-system-windows', 'menu' ) );	
 	}else{
 		$self->{_menuitem_awindow}->set_image(
 			Gtk2::Image->new_from_pixbuf(
@@ -482,8 +482,8 @@ sub fct_ret_new_menu {
 
 	#window
 	$self->{_menuitem_window} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('Select W_indow') );
-	if($icontheme->has_icon('gnome-window-manager')){
-		$self->{_menuitem_window}->set_image( Gtk2::Image->new_from_icon_name( 'gnome-window-manager', 'menu' ) );	
+	if($icontheme->has_icon('preferences-system-windows')){
+		$self->{_menuitem_window}->set_image( Gtk2::Image->new_from_icon_name( 'preferences-system-windows', 'menu' ) );	
 	}else{
 		$self->{_menuitem_window}->set_image(
 			Gtk2::Image->new_from_pixbuf(
@@ -527,9 +527,9 @@ sub fct_ret_new_menu {
 
 	#tooltip
 	$self->{_menuitem_tooltip} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('_Tooltip') );
-	#~ if($icontheme->has_icon('alacarte')){
-		#~ $self->{_menuitem_tooltip}->set_image( Gtk2::Image->new_from_icon_name( 'alacarte', 'menu' ) );		
-	#~ }else{
+	if($icontheme->has_icon('help-faq')){
+		$self->{_menuitem_tooltip}->set_image( Gtk2::Image->new_from_icon_name( 'help-faq', 'menu' ) );		
+	}else{
 		$self->{_menuitem_tooltip}->set_image(
 			Gtk2::Image->new_from_pixbuf(
 				Gtk2::Gdk::Pixbuf->new_from_file_at_size(
@@ -538,7 +538,7 @@ sub fct_ret_new_menu {
 				)
 			)
 		);
-	#~ }
+	}
 	$self->{_menu_new}->append( $self->{_menuitem_tooltip} );
 
 	#~ $self->{_menu_new}->append( Gtk2::SeparatorMenuItem->new );
@@ -580,23 +580,20 @@ sub fct_ret_actions_menu{
 	
 	$self->{_menu_actions} = Gtk2::Menu->new();
 
-	#~ $self->{_menuitem_reopen_default} = Gtk2::ImageMenuItem->new_with_mnemonic( 
-			#~ sprintf( $d->get('_Open with %s'), ''),
- 		#~ );
-	$self->{_menuitem_reopen_default} = Gtk2::ImageMenuItem->new_with_mnemonic( 
-			$d->get('_Open with default application')
- 		);
-	$self->{_menuitem_reopen_default}->set_image( Gtk2::Image->new_from_stock( 'gtk-open', 'menu' ) );
-	$self->{_menuitem_reopen_default}->set_sensitive(FALSE);
-	$self->{_menuitem_reopen_default}->set_name('item-reopen-default');
-	$self->{_menu_actions}->append( $self->{_menuitem_reopen_default} );
-
 	$self->{_menuitem_reopen} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('Open wit_h') );
 	$self->{_menuitem_reopen}->set_image( Gtk2::Image->new_from_stock( 'gtk-open', 'menu' ) );
 	$self->{_menuitem_reopen}->set_sensitive(FALSE);
 	$self->{_menuitem_reopen}->set_name('item-reopen-list');
 	$self->{_menu_actions}->append( $self->{_menuitem_reopen} );
 
+	$self->{_menuitem_show_in_folder} = Gtk2::ImageMenuItem->new_with_mnemonic( 
+			$d->get('Show in _folder')
+ 		);
+	$self->{_menuitem_show_in_folder}->set_image( Gtk2::Image->new_from_stock( 'gtk-open', 'menu' ) );
+	$self->{_menuitem_show_in_folder}->set_sensitive(FALSE);
+	$self->{_menuitem_show_in_folder}->set_name('item-reopen-default');
+	$self->{_menu_actions}->append( $self->{_menuitem_show_in_folder} );
+
 	$self->{_menuitem_rename} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('_Rename...') );
 	$self->{_menuitem_rename}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('F2'), qw/visible/ ) if $accel_group;
 	$self->{_menuitem_rename}->set_image( Gtk2::Image->new_from_stock( 'gtk-edit', 'menu' ) );
@@ -680,23 +677,20 @@ sub fct_ret_actions_menu_large{
 	
 	$self->{_menu_large_actions} = Gtk2::Menu->new();
 
-	#~ $self->{_menuitem_large_reopen_default} = Gtk2::ImageMenuItem->new_with_mnemonic( 
-			#~ sprintf( $d->get('_Open with %s'), ''),
- 		#~ );
-	$self->{_menuitem_large_reopen_default} = Gtk2::ImageMenuItem->new_with_mnemonic( 
-			$d->get('_Open with default application')
- 		);
-	$self->{_menuitem_large_reopen_default}->set_image( Gtk2::Image->new_from_stock( 'gtk-open', 'menu' ) );
-	$self->{_menuitem_large_reopen_default}->set_sensitive(FALSE);
-	$self->{_menuitem_large_reopen_default}->set_name('item-large-reopen-default');
-	$self->{_menu_large_actions}->append( $self->{_menuitem_large_reopen_default} );
-
 	$self->{_menuitem_large_reopen} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('Open wit_h') );
 	$self->{_menuitem_large_reopen}->set_image( Gtk2::Image->new_from_stock( 'gtk-open', 'menu' ) );
 	$self->{_menuitem_large_reopen}->set_sensitive(FALSE);
 	$self->{_menuitem_large_reopen}->set_name('item-large-reopen-list');
 	$self->{_menu_large_actions}->append( $self->{_menuitem_large_reopen} );
 
+	$self->{_menuitem_large_show_in_folder} = Gtk2::ImageMenuItem->new_with_mnemonic( 
+			$d->get('Show in _folder')
+ 		);
+	$self->{_menuitem_large_show_in_folder}->set_image( Gtk2::Image->new_from_stock( 'gtk-open', 'menu' ) );
+	$self->{_menuitem_large_show_in_folder}->set_sensitive(FALSE);
+	$self->{_menuitem_large_show_in_folder}->set_name('item-reopen-default');
+	$self->{_menu_large_actions}->append( $self->{_menuitem_large_show_in_folder} );
+
 	$self->{_menuitem_large_rename} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('_Rename...') );
 	$self->{_menuitem_large_rename}->set_image( Gtk2::Image->new_from_stock( 'gtk-edit', 'menu' ) );
 	$self->{_menuitem_large_rename}->set_sensitive(FALSE);
