@@ -1,6 +1,6 @@
 ###################################################
 #
-#  Copyright (C) 2008-2013 Mario Kemper <mario.kemper@gmail.com>
+#  Copyright (C) 2008-2012 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
 #
 #  This file is part of Shutter.
 #
@@ -69,14 +69,7 @@ sub web {
 		$self->{_url} = "http://".$self->{_url};
 	}
 	
-	system(
-        'gnome-web-photo',
-        '--timeout='.$self->{_timeout},
-        '--mode=photo',
-        '--width='.$self->{_width},
-        $self->{_url}, $self->{_dest_filename}
-    );
-
+	system("gnome-web-photo --timeout=$self->{_timeout} --mode=photo --width=$self->{_width} '$self->{_url}' '$self->{_dest_filename}'");
 	
 	return TRUE;
 }
